@@ -46,19 +46,15 @@ class PathChooserPrivate;
 class QTCREATOR_UTILS_EXPORT PathChooser : public QWidget
 {
     Q_OBJECT
-    Q_ENUMS(Kind)
     Q_PROPERTY(QString path READ path WRITE setPath NOTIFY pathChanged DESIGNABLE true)
     Q_PROPERTY(QString promptDialogTitle READ promptDialogTitle WRITE setPromptDialogTitle DESIGNABLE true)
     Q_PROPERTY(QString promptDialogFilter READ promptDialogFilter WRITE setPromptDialogFilter DESIGNABLE true)
     Q_PROPERTY(Kind expectedKind READ expectedKind WRITE setExpectedKind DESIGNABLE true)
-    Q_PROPERTY(QString baseDirectory READ baseDirectory WRITE setBaseDirectory DESIGNABLE true)
+    Q_PROPERTY(Utils::FilePath baseDirectory READ baseDirectory WRITE setBaseDirectory DESIGNABLE true)
     Q_PROPERTY(QStringList commandVersionArguments READ commandVersionArguments WRITE setCommandVersionArguments)
     Q_PROPERTY(bool readOnly READ isReadOnly WRITE setReadOnly DESIGNABLE true)
     // Designer does not know this type, so force designable to false:
-    Q_PROPERTY(Utils::FilePath fileName READ fileName WRITE setFileName DESIGNABLE false)
-    Q_PROPERTY(Utils::FilePath baseFileName READ baseFileName WRITE setBaseFileName DESIGNABLE false)
-    Q_PROPERTY(QColor errorColor READ errorColor WRITE setErrorColor DESIGNABLE true)
-    Q_PROPERTY(QColor okColor READ okColor WRITE setOkColor DESIGNABLE true)
+    Q_PROPERTY(Utils::FilePath filePath READ filePath WRITE setFilePath DESIGNABLE false)
 
 public:
     static QString browseButtonLabel();
@@ -75,6 +71,7 @@ public:
         Command, // A command that may or may not exist at the time of selection (e.g. result of a build)
         Any
     };
+    Q_ENUM(Kind)
 
     // Default is <Directory>
     void setExpectedKind(Kind expected);
@@ -86,24 +83,21 @@ public:
     void setPromptDialogFilter(const QString &filter);
     QString promptDialogFilter() const;
 
-    void setInitialBrowsePathBackup(const QString &path);
+    void setInitialBrowsePathBackup(const FilePath &path);
 
     bool isValid() const;
     QString errorMessage() const;
 
-    QString path() const;
+    FilePath filePath() const;
+
     QString rawPath() const; // The raw unexpanded input.
-    FilePath rawFileName() const; // The raw unexpanded input.
-    FilePath fileName() const;
+    FilePath rawFilePath() const; // The raw unexpanded input as FilePath.
 
     static QString expandedDirectory(const QString &input, const Environment &env,
                                      const QString &baseDir);
 
-    QString baseDirectory() const;
-    void setBaseDirectory(const QString &directory);
-
-    FilePath baseFileName() const;
-    void setBaseFileName(const FilePath &base);
+    FilePath baseDirectory() const;
+    void setBaseDirectory(const FilePath &base);
 
     void setEnvironment(const Environment &env);
 
@@ -151,9 +145,16 @@ public:
     using AboutToShowContextMenuHandler = std::function<void (PathChooser *, QMenu *)>;
     static void setAboutToShowContextMenuHandler(AboutToShowContextMenuHandler handler);
 
-    QColor errorColor() const;
-    QColor okColor() const;
+    void setOpenTerminalHandler(const std::function<void()> &openTerminal);
+    std::function<void()> openTerminalHandler() const;
 
+    // Deprecated. Use filePath().toString() or better suitable conversions.
+    QString path() const { return filePath().toString(); }
+
+    // this sets the placeHolderText to defaultValue and enables to use this as
+    // input value during validation if the real value is empty
+    // setting an empty QString will disable this and clear the placeHolderText
+    void setDefaultValue(const QString &defaultValue);
 private:
     bool validatePath(FancyLineEdit *edit, QString *errorMessage) const;
     // Returns overridden title or the one from <title>
@@ -172,10 +173,7 @@ signals:
 
 public slots:
     void setPath(const QString &);
-    void setFileName(const FilePath &);
-
-    void setErrorColor(const QColor &errorColor);
-    void setOkColor(const QColor &okColor);
+    void setFilePath(const FilePath &);
 
 private:
     PathChooserPrivate *d = nullptr;
